@@ -2689,6 +2689,23 @@ fn validate_rust_version_condition_min_enabled() {
     assert!(enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_min_disabled_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("2.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: Some("3".to_string()),
+            max: None,
+            equal: None,
+        },
+    );
+
+    assert!(!enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_min_same() {
     let mut rustinfo = RustInfo::new();
@@ -2706,6 +2723,23 @@ fn validate_rust_version_condition_min_same() {
     assert!(enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_min_same_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("2.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: Some("2".to_string()),
+            max: None,
+            equal: None,
+        },
+    );
+
+    assert!(enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_min_disabled_major() {
     let mut rustinfo = RustInfo::new();
@@ -2723,6 +2757,23 @@ fn validate_rust_version_condition_min_disabled_major() {
     assert!(!enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_min_disabled_major_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("2.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: Some("3".to_string()),
+            max: None,
+            equal: None,
+        },
+    );
+
+    assert!(!enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_min_disabled_minor() {
     let mut rustinfo = RustInfo::new();
@@ -2774,6 +2825,23 @@ fn validate_rust_version_condition_max_enabled() {
     assert!(enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_max_enabled_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("1.9.9".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: None,
+            max: Some("2".to_string()),
+            equal: None,
+        },
+    );
+
+    assert!(enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_max_same() {
     let mut rustinfo = RustInfo::new();
@@ -2791,6 +2859,23 @@ fn validate_rust_version_condition_max_same() {
     assert!(enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_max_same_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("2.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: None,
+            max: Some("2".to_string()),
+            equal: None,
+        },
+    );
+
+    assert!(enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_max_disabled_major() {
     let mut rustinfo = RustInfo::new();
@@ -2808,6 +2893,23 @@ fn validate_rust_version_condition_max_disabled_major() {
     assert!(!enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_max_disabled_major_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("3.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: None,
+            max: Some("2".to_string()),
+            equal: None,
+        },
+    );
+
+    assert!(!enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_max_disabled_minor() {
     let mut rustinfo = RustInfo::new();
@@ -2859,6 +2961,23 @@ fn validate_rust_version_condition_equal_same() {
     assert!(enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_equal_same_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("2.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: None,
+            max: None,
+            equal: Some("2".to_string()),
+        },
+    );
+
+    assert!(enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_equal_not_same() {
     let mut rustinfo = RustInfo::new();
@@ -2876,6 +2995,23 @@ fn validate_rust_version_condition_equal_not_same() {
     assert!(!enabled);
 }
 
+#[test]
+fn validate_rust_version_condition_equal_not_same_and_partial() {
+    let mut rustinfo = RustInfo::new();
+    rustinfo.version = Some("2.0.0".to_string());
+
+    let enabled = validate_rust_version_condition(
+        rustinfo,
+        RustVersionCondition {
+            min: None,
+            max: None,
+            equal: Some("3".to_string()),
+        },
+    );
+
+    assert!(!enabled);
+}
+
 #[test]
 fn validate_rust_version_condition_all_enabled() {
     let mut rustinfo = RustInfo::new();
